battalion package
=================

Submodules
----------

battalion.command module
------------------------

.. automodule:: battalion.command
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: battalion
    :members:
    :undoc-members:
    :show-inheritance:
